@@ -9,7 +9,7 @@ import datauri
 from watchdog.observers import Observer
 from watchdog.events import LoggingEventHandler
 
-__version__ = "1.2.4"
+__version__ = "1.2.7"
 homedir = Path.home()
 homedir = str(homedir).replace("\\", "/")
 
@@ -104,6 +104,13 @@ def downloadRepl(user, replname, initialPath=".", noWriteDir=False):
 				for file in getSubFiles(newfile):
 					files.append(file.replace("\\", "/"))
 					file = file.replace("\\", "/")
+		
+		if initialPath == ".":
+			seperator = ""
+		else:
+			seperator = f"{initialPath}/"
+
+		newfile = seperator + newfile
 	
 		if not ThisIsDir:
 			print(f"REFRESHING FILE/DIR FROM SERVER - {newfile}")
@@ -127,15 +134,18 @@ def downloadRepl(user, replname, initialPath=".", noWriteDir=False):
 			original = content
 			content = clean(content)
 
-			if initialPath == ".":
-				seperator = ""
-			else:
-				seperator = f"{initialPath}/"
+			if content == "cat: out/db: Is a directory":
+				for file in getSubFiles(newfile):
+					files.append(file.replace("\\", "/"))
+					file = file.replace("\\", "/")
+				continue
+
+			print(original)
 
 			if not noWriteDir:
-				filename = replname+"/"+seperator + newfile
+				filename = replname+"/"+newfile
 			else:
-				filename = seperator + newfile
+				filename = newfile
 
 			os.makedirs(os.path.dirname(filename), exist_ok=True)
 	
@@ -598,59 +608,27 @@ def run(repl:str, run:bool=True, stop:bool=False, restart:bool=False):
 	replname = repl.split("/")[1]
 
 	key = __sid__.strip()
-	token, url = pyrepl.get_token(user, replname, key)
 	id = get_json(user, replname, key)
-	client = pyrepl.Client(token, id, url)
-	channel = client.open('shellrun2', 'runner')
 	if run:
-		output = channel.get_output({
-			'runMain':{
-			}
-		})
-		output = str(output).replace("[", "").replace("]", "").split(", ")
-		output2 = ""
-		y = 0
-		for x in output:
-			if "output" in x: y += 1
-			if "output" in x and y == 2: out = output[output.index(x)].split("output: \"")[1].split("\"")[0]; output2 += f"{out}\n"
-		output = output2
-		output = bytes(output, "utf-8").decode("unicode_escape")
-		print(output)
-		client.close()
+		requests.post("https://replops.coolcodersj.repl.co/run", data=json.dumps({
+			"UUID": id,
+			"sid": key
+		}),
+		headers = {'Content-type': 'application/json', 'Accept': 'text/plain'})
+
 	elif stop:
-		output = channel.get_output({
-			'clear':{
-			}
-		})
-		output = str(output).replace("[", "").replace("]", "").split(", ")
-		output2 = ""
-		y = 0
-		for x in output:
-			if "output" in x: y += 1
-			if "output" in x and y == 2: out = output[output.index(x)].split("output: \"")[1].split("\"")[0]; output2 += f"{out}\n"
-		output = output2
-		output = bytes(output, "utf-8").decode("unicode_escape")
-		print(output)
-		client.close()
+		requests.post("https://replops.coolcodersj.repl.co/stop", data=json.dumps({
+			"UUID": id,
+			"sid": key
+		}),
+		headers = {'Content-type': 'application/json', 'Accept': 'text/plain'})
+
 	elif restart:
-		channel.get_output({
-			'clear':{
-			}
-		})
-		output = channel.get_output({
-			'runMain':{
-			}
-		})
-		output = str(output).replace("[", "").replace("]", "").split(", ")
-		output2 = ""
-		y = 0
-		for x in output:
-			if "output" in x: y += 1
-			if "output" in x and y == 2: out = output[output.index(x)].split("output: \"")[1].split("\"")[0]; output2 += f"{out}\n"
-		output = output2
-		output = bytes(output, "utf-8").decode("unicode_escape")
-		print(output)
-		client.close()
+		requests.post("https://replops.coolcodersj.repl.co/restart", data=json.dumps({
+			"UUID": id,
+			"sid": key
+		}),
+		headers = {'Content-type': 'application/json', 'Accept': 'text/plain'})
 
 @app.command(help="Connect to a bash shell with a remote repl.")
 def shell(repl:str):
